@@ -5,12 +5,13 @@
 extern SEXP call_subplex (SEXP x, SEXP f, SEXP tol, SEXP maxnfe, SEXP scale, SEXP hessian, SEXP rho, SEXP args);
 
 static const R_CallMethodDef callMethods[] = {
-  {"call_subplex", (DL_FUNC) &call_subplex, 8},
+  {"C_subplex", (DL_FUNC) &call_subplex, 8},
   {NULL, NULL, 0}
 };
 
 void R_init_subplex (DllInfo *info) {
   // Register routines
   R_registerRoutines(info,NULL,callMethods,NULL,NULL);
-  R_useDynamicSymbols(info,TRUE);
+  R_useDynamicSymbols(info,FALSE);
+  R_forceSymbols(info,TRUE);
 }
